@@ -4,12 +4,12 @@ find parse/tests/* -maxdepth 0 -type d | while read target
 do
     cd $root/$target
     fuzz_target=`echo $target | rev | cut -d'/' -f 1 | rev`
-    compile_go_fuzzer github.com/tdewolff/parse/tests/$fuzz_target Fuzz parse-$fuzz_target-fuzzer
+    compile_go_fuzzer . Fuzz parse-$fuzz_target gofuzz
 done
 
 find minify/tests/* -maxdepth 0 -type d | while read target
 do
     cd $root/$target
     fuzz_target=`echo $target | rev | cut -d'/' -f 1 | rev`
-    compile_go_fuzzer github.com/tdewolff/minify/tests/$fuzz_target Fuzz minify-$fuzz_target-fuzzer
+    compile_go_fuzzer . Fuzz minify-$fuzz_target gofuzz
 done
