@@ -17,9 +17,6 @@ var (
 
 ////////////////////////////////////////////////////////////////
 
-// DefaultMinifier is the default minifier.
-var DefaultMinifier = &Minifier{}
-
 // Minifier is an XML minifier.
 type Minifier struct {
 	KeepWhitespace bool
@@ -27,7 +24,7 @@ type Minifier struct {
 
 // Minify minifies XML data, it reads from r and writes to w.
 func Minify(m *minify.M, w io.Writer, r io.Reader, params map[string]string) error {
-	return DefaultMinifier.Minify(m, w, r, params)
+	return (&Minifier{}).Minify(m, w, r, params)
 }
 
 // Minify minifies XML data, it reads from r and writes to w.
